.. _further_reading:

###############
Further Reading
###############

tsam was originally designed for reducing the computational load for large-scale energy system optimization models. If you are interested
in that purpose of time series aggregation, you can find a detailed review about that topic `here <https://www.mdpi.com/1996-1073/13/3/641>`_.
If you are further interested in the impact of time series aggregation on the cost-optimal results on different energy system use cases, 
you can find a publication which validates the methods and describes their cababilites via the following `link 
<https://www.sciencedirect.com/science/article/abs/pii/S0960148117309783>`_.
A second publication introduces a method how to model model state variables (e.g. the state of charge of energy storage components) between the
aggregated typical periods which can be found `here <https://www.sciencedirect.com/science/article/pii/S0306261918300242>`_.
Finally yet importantly the potential of time series aggregation to simplify mixed integer linear problems is investigated `here
<https://www.mdpi.com/1996-1073/12/14/2825>`_.

The publications about time series aggregation for energy system optimization models published alongside the development of tsam are listed below:

* | Kotzur et al. (2018):
  | `Impact of different time series aggregation methods on optimal energy system design <https://www.sciencedirect.com/science/article/abs/pii/S0960148117309783>`_
* | Kotzur et al. (2018):
  | `Time series aggregation for energy system design: Modeling seasonal storage <https://www.sciencedirect.com/science/article/pii/S0306261918300242>`_
* | Kannengießer et al. (2019):
  | `Reducing Computational Load for Mixed Integer Linear Programming: An Example for a District and an Island Energy System <https://www.mdpi.com/1996-1073/12/14/2825>`_
* | Hoffmann et al. (2020):
  | `A Review on Time Series Aggregation Methods for Energy System Models <https://www.mdpi.com/1996-1073/13/3/641>`_
* | Hoffmann et al. (2022):
  | `The Pareto-Optimal Temporal Aggregation of Energy System Models <https://www.sciencedirect.com/science/article/abs/pii/S0306261922004342>`
